==> haskell-isomorphism-class-0.1.1-24-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-isomorphism-class.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 isomorphism-class
version:              0.1.1
visibility:           public
id:                   isomorphism-class-0.1.1-DOCWePAX6COFrsaiYA4wNl
key:                  isomorphism-class-0.1.1-DOCWePAX6COFrsaiYA4wNl
license:              MIT
copyright:            (c) 2022 Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/isomorphism-class
synopsis:             Isomorphism typeclass solving the conversion problem
description:          Lawful typeclass for lossless conversion between types.
category:             Conversion
abi:                  be83ed8d51de5cbe1fbc26a7dd91e3ac
exposed:              True
exposed-modules:      IsomorphismClass
hidden-modules:
    IsomorphismClass.Prelude IsomorphismClass.TextCompat.Array

import-dirs:          /usr/lib/ghc-9.4.8/site-local/isomorphism-class-0.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/isomorphism-class-0.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/isomorphism-class-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-isomorphism-class
hs-libraries:         HSisomorphism-class-0.1.1-DOCWePAX6COFrsaiYA4wNl
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    hashable-1.4.4.0-HcIU0jNirb1KY01FJoO6uU
    primitive-0.9.0.0-Ldr1crf6mT98Jp7aevHFeM text-2.0.2
    unordered-containers-0.2.20-BooESfmG3DbHMU6mBvbzIL
    vector-0.13.2.0-InZif5xbqP17OkTvptfKiM

haddock-interfaces:
    /usr/share/doc/haskell-isomorphism-class/html/isomorphism-class.haddock

haddock-html:         /usr/share/doc/haskell-isomorphism-class/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-isomorphism-class-0.1.1-25-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-isomorphism-class.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 isomorphism-class
version:              0.1.1
visibility:           public
id:                   isomorphism-class-0.1.1-AEJpe9NPo466Y5fRWt23cS
key:                  isomorphism-class-0.1.1-AEJpe9NPo466Y5fRWt23cS
license:              MIT
copyright:            (c) 2022 Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/isomorphism-class
synopsis:             Isomorphism typeclass solving the conversion problem
description:          Lawful typeclass for lossless conversion between types.
category:             Conversion
abi:                  6bd49c480a08e1150d5af478aacb34ec
exposed:              True
exposed-modules:      IsomorphismClass
hidden-modules:
    IsomorphismClass.Prelude IsomorphismClass.TextCompat.Array

import-dirs:          /usr/lib/ghc-9.4.8/site-local/isomorphism-class-0.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/isomorphism-class-0.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/isomorphism-class-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-isomorphism-class
hs-libraries:         HSisomorphism-class-0.1.1-AEJpe9NPo466Y5fRWt23cS
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    hashable-1.4.4.0-JPfSbBrFTKBgQKoWbpACz
    primitive-0.9.0.0-BHqivtPzLOB6VfmzYm3KVP text-2.0.2
    unordered-containers-0.2.20-DaOkK38PYRa9pF7ZwbG4ZB
    vector-0.13.2.0-5IsJnyR8rmEEUPyguFia6U

haddock-interfaces:
    /usr/share/doc/haskell-isomorphism-class/html/isomorphism-class.haddock

haddock-html:         /usr/share/doc/haskell-isomorphism-class/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
